/*
jGuard is a security framework based on top of jaas (java authentication and authorization security).
it is written for web applications, to resolve simply, access control problems.
version $Name:  $
http://sourceforge.net/projects/jguard/

Copyright (C) 2004  Charles GAY

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA


jGuard project home page:
http://sourceforge.net/projects/jguard/

*/
package net.sf.jguard.example.swing.dialog;

import java.awt.BorderLayout;
import java.awt.Dimension;
import java.awt.Frame;
import java.awt.GridLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.io.BufferedReader;
import java.io.FileReader;
import java.io.IOException;
import java.security.AccessController;
import java.security.PrivilegedActionException;
import java.security.PrivilegedExceptionAction;

import java.util.logging.Logger;
import javax.security.auth.Subject;
import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JFileChooser;
import javax.swing.JLabel;
import javax.swing.JOptionPane;
import javax.swing.JPanel;
import javax.swing.JTextField;

import net.sf.jguard.core.authorization.policy.AccessControlContextUtils;



/**
 *
 * @author <a href="mailto:diabolo512@users.sourceforge.net">Charles Gay</a>
 * @author <a href="mailto:vberetti@users.sourceforge.net">Vincent Beretti</a>
 */
public class CheckPermissionDialog extends JDialog {

	private static final Logger logger = Logger.getLogger(CheckPermissionDialog.class.getName());

	private static final long serialVersionUID = -7641435710653804135L;

	private Subject subject;

	private JTextField fileTxtField;

	public CheckPermissionDialog(Frame parentFrame,Subject subject){
		super(parentFrame,"Check Permission Dialog",true);
		this.subject = subject;

		this.setLayout(new BorderLayout());

		JPanel informationPanel = new JPanel();
		GridLayout informationLayout = new GridLayout(1,3);
		informationPanel.setLayout(informationLayout);

		JLabel fileLabel = new JLabel("  filepath :");
		fileTxtField = new JTextField(100);
		fileTxtField.setColumns(100);

		JButton browseButton = new JButton("browse ...");
		browseButton.addActionListener(new ActionListener(){
			public void actionPerformed(ActionEvent evt){
				handleBrowse();
			}
		});
		informationPanel.add(fileLabel);
		informationPanel.add(fileTxtField);
		informationPanel.add(browseButton);

		informationPanel.setPreferredSize(new Dimension(450,20));

		JPanel validationPanel=new JPanel();

		JButton tryButton = new JButton("try");
		tryButton.addActionListener(new ActionListener(){
			public void actionPerformed(ActionEvent e){
				handleTry();
			}
		});

		validationPanel.add(tryButton);


		this.add(informationPanel,BorderLayout.CENTER);
		this.add(validationPanel,BorderLayout.SOUTH);

		this.pack();
		this.setResizable(false);
		this.setLocation(parentFrame.getLocation().x,parentFrame.getLocation().y);
		this.setVisible(true);
	}


	private void handleTry(){

		final String filePath = fileTxtField.getText();
		try{
			// execute code with subject permissions and protectionDomain from currentThread
			// @see AccessControllerUtils.getStackSubjectAccessControlContext()
			AccessController.doPrivileged(new PrivilegedExceptionAction() {
				public Object run() throws SecurityException, IOException{

						BufferedReader br = new BufferedReader(new FileReader(filePath));
						br.readLine();
						br.close();

					return null;
				}
			},AccessControlContextUtils.getStackSubjectAccessControlContext(subject));

			JOptionPane.showMessageDialog(this,"You have the permissions to do that","permission allowed",JOptionPane.INFORMATION_MESSAGE);

		}catch(SecurityException e){
			logger.severe("Logged subject has no permission to read this file"+e.getMessage());
			JOptionPane.showMessageDialog(this,"You don't have the permissions to do that ","permission denied",JOptionPane.ERROR_MESSAGE);
		} catch (PrivilegedActionException e) {
			logger.severe("PrivilegedActionException ioException"+e.getMessage());
			JOptionPane.showMessageDialog(this,"You don't have the permissions to do that ","permission denied",JOptionPane.ERROR_MESSAGE);
		}
	}


	private void handleBrowse(){

		JFileChooser fileChooser = new JFileChooser();
		int state = fileChooser.showOpenDialog(this);
		if(state == JFileChooser.APPROVE_OPTION){
			String selectedPath = fileChooser.getSelectedFile().getAbsolutePath();
			fileTxtField.setText(selectedPath);
		}

	}
}
